This is a repository for pipelines and tools related to NGS data analysis.

Documentation that is currently uder development can be found [here](https://ngskit.readthedocs.io/en/latest/). At present it contains documentation for the analysing 16S rRNA amplicon data using pipeline_dada2.py - a CGAT-core pipeline that wraps DADA2 funtionality.

